# wpt-interop

Library for working with
[web-platform-tests](https://web-platfrom-tests.org) and
[Interop](https://wpt.fyi/interop-2023) data.

## Bindings

In order to facilitate using this library from other languages,
language bindings are available:

* [Python](https://pypi.org/project/wpt-interop/)
